@@ -36,7 +36,7 @@ using System.Runtime.CompilerServices;
 // The form "{Major}.{Minor}.*" will automatically update the build and revision,
 // and "{Major}.{Minor}.{Build}.*" will update just the revision.
 
-[assembly: AssemblyVersion("0.10.0.0")]
+[assembly: AssemblyVersion("0.11.0.0")]
 
 // The following attributes are used to specify the signing key for the assembly, 
 // if desired. See the Mono documentation for more information about signing.
@@ -48,7 +48,7 @@ namespace Do.Platform.Linux
 {
 	internal static class AssemblyInfo
 	{
-		public const string InstallPrefix = "/home/chris/.local";
-		public const string InstallData = "/home/chris/.local/share";
+		public const string InstallPrefix = "/usr/local";
+		public const string InstallData = "/usr/local/share";
 	}
 }
