@@ -20,7 +20,11 @@
 using System;
 using System.Reflection;
 
+#if USE_DBUS_SHARP
+using DBus;
+#else
 using NDesk.DBus;
+#endif
 using org.freedesktop.DBus;
 
 using Do.Platform.ServiceStack;
