@@ -15,6 +15,6 @@ namespace Do.Platform
 		bool RegisterKeyBinding (KeyBinding evnt);
 		bool SetKeyString (KeyBinding binding, string keyString);
 		List<KeyBinding> Bindings { get; }
-		string KeyEventToString (EventKey evnt);
+		string KeyEventToString (uint keycode, uint modifierCode);
 	}
 }
