@@ -24,14 +24,20 @@ namespace Do.Platform {
 
 	public class PreferencesChangedEventArgs : EventArgs
 	{
+		/// <summary>
+		/// The key of the changed preference.
+		/// </summary>
 		public string Key { get; private set; }
-		public object OldValue { get; private set; }
+		/// <summary>
+		/// The new value after the preference changed.
+		/// </summary>
+		public object Value { get; private set; }
 		
-		public PreferencesChangedEventArgs (string key, object oldValue)
+		public PreferencesChangedEventArgs (string key, object newValue)
 		{
 			Key = key;
-			OldValue = oldValue;
+			Value = newValue;
 		}
 	}
 	
-}
\ No newline at end of file
+}
