@@ -218,7 +218,7 @@ namespace Do.Core
 			
 			Orientation = ControlOrientation.Vertical;
 
-			if (Screen.Default.IsComposited) {
+			if ((Screen.Default.IsComposited) && (!Do.Preferences.ForceClassicWindow)) {
 				window = InterfaceManager.MaybeGetInterfaceNamed (themeName) ?? new ClassicWindow ();
 			} else {
 				window = new ClassicWindow ();
@@ -473,9 +473,9 @@ namespace Do.Core
 			} else if (key == Key.Delete ||
 				   key == Key.BackSpace) {
 				OnDeleteKeyPressEvent (evnt);
-			} else if (Services.Keybinder.Bindings.Any (k => k.KeyString == Services.Keybinder.KeyEventToString (evnt))) {
+			} else if (Services.Keybinder.Bindings.Any (k => k.KeyString == Services.Keybinder.KeyEventToString (evnt.KeyValue, (uint)evnt.State))) {
 				// User set keybindings
-				Services.Keybinder.Bindings.First (k => k.KeyString == Services.Keybinder.KeyEventToString (evnt)).Callback (evnt);
+				Services.Keybinder.Bindings.First (k => k.KeyString == Services.Keybinder.KeyEventToString (evnt.KeyValue, (uint)evnt.State)).Callback (evnt);
 			} else {
 				OnInputKeyPressEvent (evnt);
 			}
