@@ -46,7 +46,7 @@ namespace Do.Core
 	{
 		const string DefaultPluginIcon = "folder_tar";
 		
-		static IEnumerable<string> ExtensionPaths = new [] { "/Do/ItemSource", "/Do/Action" };
+		static IEnumerable<string> ExtensionPaths = new [] { "/Do/ItemSource", "/Do/Action", "/Do/DynamicItemSource" };
 
 		public static readonly IEnumerable<AddinClassifier> Classifiers =
 			new AddinClassifier [] {
@@ -204,6 +204,13 @@ namespace Do.Core
 			get { return AddinManager.GetExtensionObjects ("/Do/ItemSource").OfType<ItemSource> (); }
 		}
 
+		/// <summary>
+		/// All loaded DynamicItemSources.
+		/// </summary>
+		public static IEnumerable<DynamicItemSource> DynamicItemSources {
+			get { return AddinManager.GetExtensionObjects ("/Do/DynamicItemSource").OfType<DynamicItemSource> (); }
+		}
+
 		/// <value>
 		/// All loaded Actions.
 		/// </value>
@@ -276,28 +283,28 @@ namespace Do.Core
 		static void OnPluginChanged (object sender, ExtensionNodeEventArgs args)
 		{
 			TypeExtensionNode node = args.ExtensionNode as TypeExtensionNode;
-			
+
 			switch (args.Change) {
-			case ExtensionChange.Add:
-				try {
-					object plugin = node.GetInstance ();
-					Log<PluginManager>.Debug ("Loaded \"{0}\" from plugin.", plugin.GetType ().Name);
-				} catch (Exception e) {
-					Log<PluginManager>.Error ("Encountered error loading plugin: {0} \"{1}\"",
+				case ExtensionChange.Add:
+					try {
+						object plugin = node.GetInstance ();
+						Log<PluginManager>.Debug ("Loaded \"{0}\" from plugin.", plugin.GetType ().Name);
+					} catch (Exception e) {
+						Log<PluginManager>.Error ("Encountered error loading plugin: {0} \"{1}\"",
 							e.GetType ().Name, e.Message);
-					Log<PluginManager>.Debug (e.StackTrace);
-				}
-				break;
-			case ExtensionChange.Remove:
-				try {
-					object plugin = node.GetInstance ();
-					Log<PluginManager>.Debug ("Unloaded \"{0}\".", plugin.GetType ().Name);
-				} catch (Exception e) {
-					Log<PluginManager>.Error ("Encountered error unloading plugin: {0} \"{1}\"",
+						Log<PluginManager>.Debug (e.StackTrace);
+					}
+					break;
+				case ExtensionChange.Remove:
+					try {
+						object plugin = node.GetInstance ();
+						Log<PluginManager>.Debug ("Unloaded \"{0}\".", plugin.GetType ().Name);
+					} catch (Exception e) {
+						Log<PluginManager>.Error ("Encountered error unloading plugin: {0} \"{1}\"",
 							e.GetType ().Name, e.Message);
-					Log<PluginManager>.Debug (e.StackTrace);
-				}
-				break;
+						Log<PluginManager>.Debug (e.StackTrace);
+					}
+					break;
 			}	
 		}
 		
