@@ -49,7 +49,10 @@ namespace Do.UI
 		PluginNodeView nview;
 		SearchEntry search_entry;
 
-		new public string Name {
+
+		// This must be an explicit interface method to disambiguate between
+		// Widget.Name and IConfigurable.Name
+		string IConfigurable.Name {
 			get { return Catalog.GetString ("Plugins"); }
 		}
 
