@@ -27,18 +27,17 @@ using Mono.Unix;
 using Do.UI;
 using Do.Core;
 using Do.Platform;
+using Do.Platform.Common;
 
 namespace Do {
 
 	static class Do {
 		
-		static XKeybinder keybinder;
 		static Controller controller;
 		static UniverseManager universe_manager;
 
-		public static CorePreferences Preferences { get; private set; } 
-		public static CoreKeybindings Keybindings { get; private set; } 
-
+		public static CorePreferences Preferences { get; private set; }
+		
 		internal static void Main (string [] args)
 		{
 			Catalog.Init ("gnome-do", AssemblyInfo.LocaleDirectory);
@@ -55,8 +54,6 @@ namespace Do {
 
 			Preferences = new CorePreferences ();
 
-			Keybindings = new CoreKeybindings ();
-
 			// Now we can set the preferred log level.
 			if (Preferences.QuietStart)
 				Log.DisplayLevel = LogLevel.Error;
@@ -65,7 +62,7 @@ namespace Do {
 				Log.DisplayLevel = LogLevel.Debug;
 
 			try {
-				Util.SetProcessName ("gnome-do");
+				Services.System.SetProcessName ("gnome-do");
 			} catch (Exception e) {
 				Log.Error ("Failed to set process name: {0}", e.Message);
 			}
@@ -73,12 +70,9 @@ namespace Do {
 			Controller.Initialize ();
 			UniverseManager.Initialize ();
 			
-			keybinder = new XKeybinder ();
-			SetupKeybindings ();
-
 			if (!Preferences.QuietStart)
 				Controller.Summon ();
-			
+
 			Gtk.Application.Run ();
 			
 			RelevanceProvider.Serialize (RelevanceProvider.DefaultProvider);
@@ -100,37 +94,5 @@ namespace Do {
 				return universe_manager;
 			}
 		}
-
-		static void SummonKeyCb (object sender, PreferencesChangedEventArgs e)
-		{
-			try {
-				if (e.OldValue != null)
-					keybinder.Unbind (e.OldValue as string);
-				keybinder.Bind (Keybindings.GetKeybinding ("SummonKey"), OnActivate);
-			} catch (Exception ex) {
-				Log.Error ("Could not bind summon key: {0}", ex.Message);
-				Log.Debug (ex.StackTrace);
-			}
-
-		}
-		
-		static void SetupKeybindings ()
-		{
-			try {
-				keybinder.Bind (Keybindings.GetKeybinding ("SummonKey"), OnActivate);
-			} catch (Exception e) {
-				Log.Error ("Could not bind summon key: {0}", e.Message);
-				Log.Debug (e.StackTrace);
-			}
-
-			// Watch preferences for changes to the keybinding so we
-			// can change the binding when the user reassigns it.
-			Keybindings.RegisterNotification ("SummonKey", SummonKeyCb);
-		}
-		
-		static void OnActivate (object sender, EventArgs e)
-		{
-			controller.Summon ();
-		}
 	}
-}
+}
\ No newline at end of file
