@@ -24,7 +24,7 @@
 #ifndef __DO_KEY_BINDER_H__
 #define __DO_KEY_BINDER_H__
 
-#include <glib/gtypes.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
